.. _developer:

##########################
Developer Reference Manual
##########################

:Release: |version|
:Date: |today|

The intended audience of this guide is developers who use Py-ART, for a more
generate introduction to Py-ART aimed at users see the :ref:`user`.

This guide provides  for all functions modules, and classes within Py-ART,
both those in the public API and private functions, modules and classes. 
Documentation is broken down by directory and module.

.. toctree::
    :maxdepth: 2
    
    core
    io
    aux_io
    config
    correct
    retrieve
    graph
    map
    testing
    _debug_info
